@@ -9,6 +9,7 @@ import math
 import numpy as np
 from PyFin.Math.Accumulators.IAccumulators import Accumulator
 from PyFin.Math.Accumulators.IAccumulators import Pow
+import bisect
 
 
 def _checkParameterList(dependency):
@@ -402,4 +403,93 @@ class Kurtosis(StatelessAccumulator):
         self._kurtosis.push(data)
 
     def result(self):
-        return self._kurtosis.result()
\ No newline at end of file
+        return self._kurtosis.result()
+
+
+class Rank(StatelessAccumulator):
+    def __init__(self, dependency='x'):
+        super(Rank, self).__init__(dependency)
+        self._thisList = []
+        self._sortedList = []
+        self._rank = []
+
+    def push(self, data):
+        value = super(Rank, self).push(data)
+        if np.isnan(value):
+            return np.nan
+        else:
+            self._thisList.append(value)
+            self._sortedList = sorted(self._thisList)
+
+    def result(self):
+        self._rank = [bisect.bisect_left(self._sortedList, x) for x in self._thisList]
+        return self._rank
+
+
+class LevelList(StatelessAccumulator):
+    def __init__(self, dependency='x', ):
+        super(LevelList, self).__init__(dependency)
+        self._levelList = []
+        self._thisList = []
+
+    def push(self, data):
+        value = super(LevelList, self).push(data)
+        if np.isnan(value):
+            return np.nan
+        else:
+            self._thisList.append(value)
+            if len(self._thisList) == 1:
+                self._levelList.append(1.0)
+            else:
+                self._levelList.append(self._thisList[-1] / self._thisList[0])
+
+    def result(self):
+        return self._levelList
+
+
+class LevelValue(StatelessAccumulator):
+    def __init__(self, dependency='x'):
+        super(LevelValue, self).__init__(dependency)
+        self._thisList = []
+
+    def push(self, data):
+        value = super(LevelValue, self).push(data)
+        if np.isnan(value):
+            return np.nan
+        else:
+            self._thisList.append(value)
+            if len(self._thisList) == 1:
+                self._levelValue = 1.0
+            else:
+                self._levelValue = self._thisList[-1] / self._thisList[0]
+
+    def result(self):
+        return self._levelValue
+
+
+class AutoCorrelation(StatelessAccumulator):
+    def __init__(self, lags, dependency='x'):
+        super(AutoCorrelation, self).__init__(dependency)
+        self._lags = lags
+        self._thisList = []
+
+    def push(self, data):
+        value = super(AutoCorrelation, self).push(data)
+        if np.isnan(value):
+            return np.nan
+        else:
+            self._thisList.append(value)
+
+    def result(self):
+        if len(self._thisList) <= self._lags:
+            raise ValueError ("time-series length should be more than lags however\n"
+                              "time-series length is: {0} while lags is: {1}".format(len(self._thisList), self._lags))
+        else:
+            try:
+                self._VecForward = self._thisList[0:len(self._thisList) - self._lags]
+                self._VecBackward = self._thisList[-len(self._thisList) + self._lags - 1:-1]
+                self._AutoCorrMatrix = np.cov(self._VecBackward, self._VecForward) / \
+                                (np.std(self._VecBackward) * np.std(self._VecForward))
+            except ZeroDivisionError:
+                return np.nan
+            return self._AutoCorrMatrix[0, 1]
