@@ -30,12 +30,18 @@ from PyFin.Math.Accumulators import MovingCorrelationMatrix
 from PyFin.Math.Accumulators import MovingProduct
 from PyFin.Math.Accumulators import MovingCenterMoment
 from PyFin.Math.Accumulators import MovingSkewness
-from PyFin.Math.Accumulators import MovingTsMaxPos
-from PyFin.Math.Accumulators import MovingTsMinPos
+from PyFin.Math.Accumulators import MovingMaxPos
+from PyFin.Math.Accumulators import MovingMinPos
 from PyFin.Math.Accumulators import MovingKurtosis
 from PyFin.Math.Accumulators import MovingRSV
 from PyFin.Math.Accumulators import MACD
 from PyFin.Math.Accumulators import XAverage
+from PyFin.Math.Accumulators import MovingRank
+from PyFin.Math.Accumulators import MovingKDJ
+from PyFin.Math.Accumulators import MovingBias
+from PyFin.Math.Accumulators import MovingAroon
+from PyFin.Math.Accumulators import MovingLevel
+from PyFin.Math.Accumulators import MovingAutoCorrelation
 
 class TestStatefulAccumulators(unittest.TestCase):
     def setUp(self):
@@ -604,7 +610,7 @@ class TestStatefulAccumulators(unittest.TestCase):
 
     def testMovingTsMaxPos(self):
         window = 10
-        maxPos = MovingTsMaxPos(window, dependency='x')
+        maxPos = MovingMaxPos(window, dependency='x')
 
         con = []
         for i, value in enumerate(self.sample):
@@ -623,7 +629,7 @@ class TestStatefulAccumulators(unittest.TestCase):
 
     def testMovingTsMinPos(self):
         window = 10
-        minPos = MovingTsMinPos(window, dependency='x')
+        minPos = MovingMinPos(window, dependency='x')
 
         con = []
         for i, value in enumerate(self.sample):
@@ -718,6 +724,133 @@ class TestStatefulAccumulators(unittest.TestCase):
                                                              "calculated ema macd diff: {2:f}".format(i, expected, calculated))
 
 
+    def testMovingRank(self):
+        window = 10
+        mk = MovingRank(window, dependency='x')
+
+        con = []
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            mk.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                calculated = mk.result()
+                expected = np.argsort(np.argsort(con))
+                self.assertListEqual(list(expected), calculated, "at index {0:d}\n"
+                                                            "expected rank:   {1}\n"
+                                                            "calculated rank: {2}".format(i, expected, calculated))
+
+
+    def testMovingKDJ(self):
+        window = 10
+        k=3
+        d=3
+        mk = MovingKDJ(window, dependency='x')
+
+        con = []
+        this_j = []
+        tmp_flag = True
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            mk.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            this_rsv = (value - np.min(con)) / (np.max(con) - np.min(con))
+            if len(con) == 1:
+                this_j.append(np.nan)
+            else:
+                if len(con) == 2:
+                    this_k = (0.5 * (k - 1) + this_rsv) / k
+                    this_d = (0.5 * (d - 1) + this_k) / d
+                else:
+                    this_k = (this_k * (k - 1) + this_rsv) / k
+                    this_d = (this_d * (d - 1) + this_k) / d
+                this_j.append(3 * this_k - 2 * this_d)
+
+            if i >= window - 1:
+                expected = this_j[-1]
+                calculated = mk.result()
+                self.assertAlmostEqual(expected, calculated, 8, "at index {0:d}\n"
+                                                                "expected kdj:   {1:f}\n"
+                                                                "calculated kdj: {2:f}".format(i, expected, calculated))
+
+
+
+    def testMovingBias(self):
+        window = 10
+        mb = MovingBias(window, dependency='x')
+        con = []
+
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            mb.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                calculated = mb.result()
+                expected = value / np.mean(con) - 1
+                self.assertAlmostEqual(expected, calculated, 8, "at index {0:d}\n"
+                                                                "expected bias:   {1:f}\n"
+                                                                "calculated bias: {2:f}".format(i, expected, calculated))
+
+
+    def testMovingAroon(self):
+        window = 10
+        ma = MovingAroon(window, dependency='x')
+        con = []
+
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            ma.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                calculated = ma.result()
+                expected = (con.index(np.max(con)) - con.index(np.min(con))) / window
+                self.assertAlmostEqual(expected, calculated, 8, "at index {0:d}\n"
+                                                                "expected aroon:  {1:f}\n"
+                                                                "calculated aroon:{2:f}".format(i, expected, calculated))
+
+
+    def testMovingLevel(self):
+        window = 10
+        ml = MovingLevel(window, dependency='x')
+        con = []
+
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            ml.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                calculated = ml.result()
+                expected = con[-1] / con[0]
+                self.assertAlmostEqual(expected, calculated, 8, "at index {0:d}\n"
+                                                                "expected level:   {1:f}\n"
+                                                                "calculated level: {2:f}".format(i, expected, calculated))
+
+
+    def testMovingAutoCorrelation(self):
+        window = 10
+        lags = 2
+        ma = MovingAutoCorrelation(window, lags, dependency='x')
+        con = []
+
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            ma.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                calculated = ma.result()
+                con_forward = con[0:window - lags]
+                con_backward = con[-window + lags - 1 : -1]
+                expected = np.cov(con_backward, con_forward) / (np.std(con_forward) * np.std(con_backward))
+                self.assertAlmostEqual(expected[0, 1], calculated, 8, "at index of {0:d}\n"
+                                                                        "expected autoCorr:  {1:f}\n"
+                                                                        "calculated autoCorr:{2:f}".format(i, expected[0,1],
+                                                                                                           calculated))
 
 if __name__ == '__main__':
     unittest.main()
